pub async fn get_cron_job_invocations_page(
client: &WasmerClient,
owner: impl Into<String>,
name: impl Into<String>,
cron_job: impl AsRef<str>,
invocation_after: Option<String>,
invocation_first: Option<i32>,
start: Option<OffsetDateTime>,
end: Option<OffsetDateTime>,
) -> Result<(CronJobWithInvocations, Paginated<CronJobInvocation>), Error>Expand description
Retrieve one page of invocations for a cron job. The cron job can be referenced by id or name.