get_package_version_numbers

Function get_package_version_numbers 

pub async fn get_package_version_numbers(
    client: &WasmerClient,
    name: String,
) -> Result<Option<Vec<String>>, Error>
Retrieve the published version numbers of a package, if it exists.

Returns None when the package does not exist in the registry, and an (possibly empty) list of version strings otherwise.