pub async fn rotate_s3_credentials(
client: &WasmerClient,
volume_id: Id,
) -> Result<RotateS3CredentialsPayload, Error>Expand description
Rotate the S3 credentials of a single app volume, identified by its
AppVolume id.
pub async fn rotate_s3_credentials(
client: &WasmerClient,
volume_id: Id,
) -> Result<RotateS3CredentialsPayload, Error>Rotate the S3 credentials of a single app volume, identified by its
AppVolume id.